@@ -70,3 +70,25 @@ def comma_list(strings, junction="and"):
         return strings[0] + " " + junction + " " + strings[1]
     else:
         return ', '.join(strings[:-1]) + ", " + junction + " " + strings[-1]
+
+
+def ordinal(n):
+    """
+    Returns the ordinal string for the number n (i.e., 0th, 1st, 2nd,
+    etc.)
+    """
+    digits = str(n)
+    if digits.endswith('11'):
+        return digits + 'th'
+    elif digits.endswith('12'):
+        return digits + 'th'
+    elif digits.endswith('13'):
+        return digits + 'th'
+    elif digits.endswith('1'):
+        return digits + 'st'
+    elif digits.endswith('2'):
+        return digits + 'nd'
+    elif digits.endswith('3'):
+        return digits + 'rd'
+    else:
+        return digits + 'th'
