@@ -753,6 +753,49 @@ else:
     (True, 1, 'from math import cos, sin', 'from math import ___'),
     (True, 1, 'from math import cos, sin', 'from math import cos, sin'),
     (True, 1, 'from math import cos, sin', 'from math import sin, cos'),
+
+    # Try/except matching
+    (
+        True, 1,
+        'try:\n  pass\nexcept ValueError as e:\n  pass',
+        'try:\n  ___\nexcept _ as e:\n  ___',
+    ), # Note: it's horrible that 'e' has to match exactly here...
+    (
+        True, 1,
+        'try:\n  pass\nexcept ValueError:\n  pass\nexcept TypeError:\n pass',
+        'try:\n  ___\nexcept _:\n  ___\nexcept _:\n  ___',
+    ),
+    # Note: doesn't feel great that we need to match order/number of
+    # excepts, as well as presence/absence of as clause for each.
+    (
+        True, 1,
+        'try:\n  pass\nexcept ValueError:\n  pass\nfinally:\n pass',
+        'try:\n  ___\nexcept _:\n  ___\nfinally:\n  ___',
+    ),
+    (
+        True, 1,
+        'try:\n  pass\nfinally:\n pass',
+        'try:\n  ___\nfinally:\n  ___',
+    ),
+
+    # With matching
+    (
+        True, 1,
+        'with open("a", "r") as fin:\n  fin.read()',
+        'with _ as _:\n  ___',
+    ),
+    (
+        True, 1,
+        'with handler:\n  code',
+        'with _:\n  ___',
+    ),
+    (
+        True, 1,
+        'with one, two as x:\n  code',
+        'with _, _ as _:\n  ___',
+    ),
+    # Note: Kinda sucks that we've got to match ordering & number of
+    # withitems, etc. TODO: allow sequence vars in withitems?
 ]
 
 # These tests fail, but in the future, maybe they could pass?
@@ -785,6 +828,17 @@ def f(___args___):
 
     # TODO: Fails because of default matching bug
     (True, 1, 'def f(x=9, y=10):\n  return x', 'def _f_(___=_):\n  ___'),
+
+    # TODO: This fails because the 'name' field of an ast.ExceptHandler
+    # is just a string, and node_is_bindable returns False for that. We
+    # ideally need some way of saying that a string node is bindable as a
+    # Name(id=value, ctx=None) IF the node is a 'name' filed of an
+    # ast.ExceptHandler, but that's not easy to figure out...
+    (
+        True, 1,
+        'try:\n  pass\nexcept ValueError as e:\n  pass',
+        'try:\n  ___\nexcept _ as _:\n  ___',
+    )
 ]
 
 
