@@ -475,20 +475,21 @@ def get_task_info(course, semester):
             # Graft static task info into pset task entry
             task.update(result["tasks"][task["id"]])
 
-    # Augment exercise info
+    # Augment exercise info if it's present
     exfmtmap = _CONFIG.get("EXERCISE_URLS", {}).get(course, {})
-    for egroup in result["exercises"]:
-        if 'url' not in egroup:
-            for prefix in exfmtmap:
-                if egroup["group"].startswith(prefix):
-                    egroup["url"] = exfmtmap[prefix].format(
-                        semester=semester,
-                        group=egroup["group"]
-                    )
+    if 'exercises' in result:
+        for egroup in result["exercises"]:
+            if 'url' not in egroup:
+                for prefix in exfmtmap:
+                    if egroup["group"].startswith(prefix):
+                        egroup["url"] = exfmtmap[prefix].format(
+                            semester=semester,
+                            group=egroup["group"]
+                        )
 
-        # No prefix matches perhaps
-        if 'url' not in egroup:
-            egroup["url"] = '#'
+            # No prefix matches perhaps
+            if 'url' not in egroup:
+                egroup["url"] = '#'
 
     return result
 
